/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.kernel.util;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.util.transport.MulticastTransport;

import java.lang.reflect.Field;

/**
 * @author Daniel Sanz
 */
public class LicenseValidationTransportUtil {

	public static void stopMulticastTransportThread() {
		try {
			ClassLoader classLoader = PortalClassLoaderUtil.getClassLoader();

			Class licenseManagerClass = classLoader.loadClass(
				"com.liferay.portal.license.LicenseManager");

			Field[] fields = licenseManagerClass.getDeclaredFields();

			for (Field field : fields) {
				Class<?> type = field.getType();

				String typeName = type.getName();

				if (!typeName.equals(
						"com.liferay.util.transport.MulticastTransport")) {

					continue;
				}

				field.setAccessible(true);

				try {
					Object value = field.get(null);

					MulticastTransport multicastTransport =
						(MulticastTransport)value;

					if (multicastTransport != null) {
						multicastTransport.disconnect();
					}
				}
				catch (IllegalAccessException iae) {
					iae.printStackTrace();
				}
				finally {
					field.setAccessible(false);
				}
			}
		}
		catch (ClassNotFoundException cnfe) {
			if (_log.isDebugEnabled()) {
				_log.debug(cnfe);
			}
		}
	}

	private static Log _log = LogFactoryUtil.getLog(
		LicenseValidationTransportUtil.class);

}