/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.spring.hibernate;

import com.liferay.portal.kernel.util.CentralizedThreadLocal;
import com.liferay.portal.kernel.util.InitialThreadLocal;
import com.liferay.portal.kernel.util.ReflectionUtil;

import java.lang.reflect.Field;
import java.lang.reflect.Modifier;

import java.util.HashMap;
import java.util.Map;

import org.springframework.core.NamedThreadLocal;
import org.springframework.transaction.support.ResourceHolder;
import org.springframework.transaction.support.TransactionSynchronizationManager;

/**
 * @author Shuyang Zhou
 */
public class SpringHibernateThreadLocalUtil {

	public static <T> T getResource(Object key) {
		Map<Object, Object> resources = _resourcesThreadLocal.get();

		if (resources == null) {
			return null;
		}

		Object resource = resources.get(key);

		if (resource instanceof ResourceHolder) {
			ResourceHolder resourceHolder = (ResourceHolder)resource;

			if (resourceHolder.isVoid()) {
				resources.remove(key);

				if (resources.isEmpty()) {
					_resourcesThreadLocal.remove();
				}

				return null;
			}
		}

		return (T)resource;
	}

	public static <T> T setResource(Object key, Object resource) {
		Map<Object, Object> resources = _resourcesThreadLocal.get();

		Object oldResource = null;

		if (resource == null) {
			if (resources == null) {
				return null;
			}

			oldResource = resources.remove(key);

			if (resources.isEmpty()) {
				_resourcesThreadLocal.remove();
			}
		}
		else {
			if (resources == null) {
				resources = new HashMap<Object, Object>();

				_resourcesThreadLocal.set(resources);
			}

			oldResource = resources.put(key, resource);
		}

		if (oldResource instanceof ResourceHolder) {
			ResourceHolder resourceHolder = (ResourceHolder)oldResource;

			if (resourceHolder.isVoid()) {
				oldResource = null;
			}
		}

		return (T)oldResource;
	}

	private static final ThreadLocal<Map<Object, Object>> _resourcesThreadLocal;

	static {
		try {
			Field nameField = ReflectionUtil.getDeclaredField(
				NamedThreadLocal.class, "name");

			ThreadLocal<?> resourcesThreadLocal = null;

			for (Field field : ReflectionUtil.getDeclaredFields(
					TransactionSynchronizationManager.class)) {

				if (Modifier.isStatic(field.getModifiers()) &&
					ThreadLocal.class.isAssignableFrom(field.getType())) {

					ThreadLocal<Object> threadLocal =
						(ThreadLocal<Object>)field.get(null);

					Object value = threadLocal.get();

					if (threadLocal instanceof NamedThreadLocal) {
						threadLocal = new InitialThreadLocal<Object>(
							(String)nameField.get(threadLocal), null);
					}
					else {
						threadLocal = new CentralizedThreadLocal<Object>(false);
					}

					if (value != null) {
						threadLocal.set(value);
					}

					field.set(null, threadLocal);

					String name = field.getName();

					if (name.equals("resources")) {
						resourcesThreadLocal = threadLocal;
					}
				}
			}

			if (resourcesThreadLocal == null) {
				throw new ExceptionInInitializerError(
					"Unable to locate \"resources\" thread local field from " +
						TransactionSynchronizationManager.class);
			}

			_resourcesThreadLocal =
				(ThreadLocal<Map<Object, Object>>)resourcesThreadLocal;
		}
		catch (Exception e) {
			throw new ExceptionInInitializerError(e);
		}
	}

}