/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.staging.permission;

import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.staging.StagingUtil;
import com.liferay.portal.model.User;
import com.liferay.portal.security.permission.PermissionChecker;
import com.liferay.portal.service.ResourceBlockLocalServiceUtil;

import java.util.List;

import javax.portlet.PortletRequest;

/**
 * @author Tomas Polesovsky
 */
public class StagingPermissionChecker implements PermissionChecker {

	public StagingPermissionChecker(PermissionChecker permissionChecker) {
		_permissionChecker = permissionChecker;
	}

	public PermissionChecker getPermissionChecker() {
		return _permissionChecker;
	}

	@Override
	public PermissionChecker clone() {
		return new StagingPermissionChecker(_permissionChecker.clone());
	}

	@Override
	public long getCompanyId() {
		return _permissionChecker.getCompanyId();
	}

	@Override
	public List<Long> getGuestResourceBlockIds(
		long companyId, long groupId, String name, String actionId) {

		return _permissionChecker.getGuestResourceBlockIds(
			companyId, groupId, name, actionId);
	}

	@Override
	public List<Long> getOwnerResourceBlockIds(
		long companyId, long groupId, String name, String actionId) {

		return _permissionChecker.getOwnerResourceBlockIds(
			companyId, groupId, name, actionId);
	}

	@Override
	public long getOwnerRoleId() {
		return _permissionChecker.getOwnerRoleId();
	}

	@Override
	public List<Long> getResourceBlockIds(
		long companyId, long groupId, long userId, String name,
		String actionId) {

		return _permissionChecker.getResourceBlockIds(
			companyId, groupId, userId, name, actionId);
	}

	@Override
	public long[] getRoleIds(long userId, long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.getRoleIds(userId, liveGroupId);
	}

	@Override
	public User getUser() {
		return _permissionChecker.getUser();
	}

	@Override
	public long getUserId() {
		return _permissionChecker.getUserId();
	}

	@Override
	public boolean hasOwnerPermission(
		long companyId, String name, long primKey, long ownerId,
		String actionId) {

		return _permissionChecker.hasOwnerPermission(
			companyId, name, primKey, ownerId, actionId);
	}

	@Override
	public boolean hasOwnerPermission(
		long companyId, String name, String primKey, long ownerId,
		String actionId) {

		return _permissionChecker.hasOwnerPermission(
			companyId, name, primKey, ownerId, actionId);
	}

	@Override
	public boolean hasPermission(
		long groupId, String name, long primKey, String actionId) {

		if (ResourceBlockLocalServiceUtil.isSupported(name)) {
			return _permissionChecker.hasPermission(
				groupId, name, primKey, actionId);
		}

		long liveGroupId = getLiveGroupId(groupId);

		if (liveGroupId != groupId) {
			if (primKey == groupId) {
				primKey = liveGroupId;
			}
		}

		return _permissionChecker.hasPermission(
			liveGroupId, name, primKey, actionId);
	}

	@Override
	public boolean hasPermission(
		long groupId, String name, String primKey, String actionId) {

		if (ResourceBlockLocalServiceUtil.isSupported(name)) {
			return _permissionChecker.hasPermission(
				groupId, name, primKey, actionId);
		}

		long liveGroupId = getLiveGroupId(groupId);

		if (liveGroupId != groupId) {
			if (primKey.equals(String.valueOf(groupId))) {
				primKey = String.valueOf(liveGroupId);
			}
		}

		return _permissionChecker.hasPermission(
			liveGroupId, name, primKey, actionId);
	}

	@Override
	public boolean hasUserPermission(
		long groupId, String name, String primKey, String actionId,
		boolean checkAdmin) {

		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.hasUserPermission(
			liveGroupId, name, primKey, actionId, checkAdmin);
	}

	@Override
	public void init(User user) {
		_permissionChecker.init(user);
	}

	@Override
	public boolean isCheckGuest() {
		return _permissionChecker.isCheckGuest();
	}

	@Override
	public boolean isCommunityAdmin(long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.isCommunityAdmin(liveGroupId);
	}

	@Override
	public boolean isCommunityOwner(long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.isCommunityOwner(liveGroupId);
	}

	@Override
	public boolean isCompanyAdmin() {
		return _permissionChecker.isCompanyAdmin();
	}

	@Override
	public boolean isCompanyAdmin(long companyId) {
		return _permissionChecker.isCompanyAdmin(companyId);
	}

	@Override
	public boolean isContentReviewer(long companyId, long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.isContentReviewer(companyId, liveGroupId);
	}

	@Override
	public boolean isGroupAdmin(long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.isGroupAdmin(liveGroupId);
	}

	@Override
	public boolean isGroupMember(long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.isGroupMember(liveGroupId);
	}

	@Override
	public boolean isGroupOwner(long groupId) {
		long liveGroupId = getLiveGroupId(groupId);

		return _permissionChecker.isGroupOwner(liveGroupId);
	}

	@Override
	public boolean isOmniadmin() {
		return _permissionChecker.isOmniadmin();
	}

	@Override
	public boolean isOrganizationAdmin(long organizationId) {
		return _permissionChecker.isOrganizationAdmin(organizationId);
	}

	@Override
	public boolean isOrganizationOwner(long organizationId) {
		return _permissionChecker.isOrganizationOwner(organizationId);
	}

	@Override
	public boolean isSignedIn() {
		return _permissionChecker.isSignedIn();
	}

	@Override
	public void resetValues() {
		_permissionChecker.resetValues();
	}

	@Override
	public void setValues(PortletRequest portletRequest) {
		_permissionChecker.setValues(portletRequest);
	}

	protected long getLiveGroupId(long groupId) {
		try {
			return StagingUtil.getLiveGroupId(groupId);
		}
		catch (Exception e) {
			_log.error("Unable to get live group for group " + groupId);
		}

		return groupId;
	}

	private final PermissionChecker _permissionChecker;

	private static Log _log = LogFactoryUtil.getLog(
		StagingPermissionChecker.class);

}