/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.upgrade.v6_1_0;

import com.liferay.portal.kernel.upgrade.BaseUpgradePortletPreferences;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portlet.PortletPreferencesFactoryUtil;

import javax.portlet.PortletPreferences;

/**
 * @author Tamas Molnar
 */
public class UpgradeIFrame extends BaseUpgradePortletPreferences {

	@Override
	protected String[] getPortletIds() {
		return new String[] {"48_INSTANCE_%"};
	}

	protected void upgradePassword(PortletPreferences portletPreferences)
		throws Exception {

		String password = GetterUtil.getString(
			portletPreferences.getValue("password", null));

		if (Validator.isNotNull(password)) {
			portletPreferences.setValue("formPassword", password);
		}

		portletPreferences.reset("password");
	}

	@Override
	protected String upgradePreferences(
			long companyId, long ownerId, int ownerType, long plid,
			String portletId, String xml)
		throws Exception {

		PortletPreferences portletPreferences =
			PortletPreferencesFactoryUtil.fromXML(
				companyId, ownerId, ownerType, plid, portletId, xml);

		upgradePassword(portletPreferences);
		upgradeUserName(portletPreferences);

		return PortletPreferencesFactoryUtil.toXML(portletPreferences);
	}

	protected void upgradeUserName(PortletPreferences portletPreferences)
		throws Exception {

		String userName = GetterUtil.getString(
			portletPreferences.getValue("userName", null));

		if (Validator.isNull(userName)) {
			userName = GetterUtil.getString(
				portletPreferences.getValue("user-name", null));
		}

		if (Validator.isNotNull(userName)) {
			portletPreferences.setValue("formUserName", userName);
		}

		portletPreferences.reset("user-name");
		portletPreferences.reset("userName");
	}

}