/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.upgrade.v6_2_0;

import com.liferay.portal.kernel.dao.jdbc.DataAccess;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.upgrade.UpgradeProcess;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.upgrade.AutoBatchPreparedStatementUtil;
import com.liferay.util.dao.orm.CustomSQLUtil;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;

/**
 * @author Julio Camarero
 */
public class UpgradePortletPreferences extends UpgradeProcess {

	protected void deletePortletPreferences(long portletPreferencesId)
		throws Exception {

		if (_log.isDebugEnabled()) {
			_log.debug("Deleting portlet preferences " + portletPreferencesId);
		}

		runSQL(
			"delete from PortletPreferences where portletPreferencesId = " +
				portletPreferencesId);
	}

	@Override
	protected void doUpgrade() throws Exception {
		Connection con = null;
		PreparedStatement ps1 = null;
		PreparedStatement ps2 = null;
		ResultSet rs = null;

		try {
			con = DataAccess.getUpgradeOptimizedConnection();

			StringBundler sb = new StringBundler(7);

			sb.append("select PortletPreferences.portletPreferencesId, ");
			sb.append("PortletPreferences.plid,");
			sb.append("PortletPreferences.portletId, Layout.typeSettings ");
			sb.append("from PortletPreferences inner join Layout on ");
			sb.append("PortletPreferences.plid = Layout.plid where ");
			sb.append("preferences like '%<portlet-preferences />%' or ");
			sb.append("preferences like '' or ? IS NULL");

			String sql = sb.toString();

			sql = CustomSQLUtil.replaceIsNull(sql);

			sql = StringUtil.replace(sql, "?", "preferences");

			ps1 = con.prepareStatement(sql);

			rs = ps1.executeQuery();

			ps2 = AutoBatchPreparedStatementUtil.autoBatch(
				con.prepareStatement(
					"delete from PortletPreferences where " +
						"portletPreferencesId = ?"));

			while (rs.next()) {
				long portletPreferencesId = rs.getLong("portletPreferencesId");
				String portletId = GetterUtil.getString(
					rs.getString("portletId"));
				String typeSettings = GetterUtil.getString(
					rs.getString("typeSettings"));

				if (typeSettings.contains(portletId)) {
					continue;
				}

				if (_log.isDebugEnabled()) {
					_log.debug(
						"Deleting portlet preferences " + portletPreferencesId);
				}

				ps2.setLong(1, portletPreferencesId);

				ps2.addBatch();
			}

			ps2.executeBatch();
		}
		finally {
			DataAccess.cleanUp(ps1);
			DataAccess.cleanUp(con, ps2, rs);
		}
	}

	private static Log _log = LogFactoryUtil.getLog(
		UpgradePortletPreferences.class);

}