/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.xml;

import com.liferay.portal.kernel.memory.EqualityWeakReference;

import java.lang.ref.Reference;
import java.lang.ref.ReferenceQueue;

import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.dom4j.DocumentFactory;
import org.dom4j.Namespace;
import org.dom4j.QName;

/**
 * @author Jorge Díaz
 * @author Tina Tian
 */
public class QNameCache extends org.dom4j.tree.QNameCache {

	public QNameCache(DocumentFactory documentFactory) {
		super(documentFactory);

		_documentFactory = documentFactory;

		namespaceCache =
			new ConcurrentHashMap<
				EqualityWeakReference<Namespace>, Map<String, QName>>();

		noNamespaceCache =
			new ConcurrentHashMap<EqualityWeakReference<String>, QName>();
	}

	@Override
	public QName get(String name) {
		_cleanReference(noNamespaceCache, _noNamespaceCacheReferenceQueue);

		QName qName = null;

		if (name == null) {
			name = "";
		}
		else {
			qName = (QName)noNamespaceCache.get(
				new EqualityWeakReference<String>(name));
		}

		if (qName == null) {
			qName = createQName(name);

			qName.setDocumentFactory(_documentFactory);

			noNamespaceCache.put(
				new EqualityWeakReference<String>(
					name, _noNamespaceCacheReferenceQueue),
				qName);
		}

		return qName;
	}

	@Override
	public QName get(String name, Namespace namespace) {
		if (namespace == Namespace.NO_NAMESPACE) {
			return get(name);
		}

		return super.get(name, namespace);
	}

	@Override
	public QName get(String localName, Namespace namespace, String qName) {
		if (namespace == Namespace.NO_NAMESPACE) {
			return get(localName);
		}

		return super.get(localName, namespace, qName);
	}

	@Override
	public List<String> getQNames() {
		_cleanReference(namespaceCache, _namespaceCacheReferenceQueue);
		_cleanReference(noNamespaceCache, _noNamespaceCacheReferenceQueue);

		return super.getQNames();
	}

	@Override
	protected Map<?, ?> createMap() {
		return new ConcurrentHashMap<String, QName>();
	}

	@Override
	protected Map<?, ?> getNamespaceCache(Namespace namespace) {
		_cleanReference(namespaceCache, _namespaceCacheReferenceQueue);

		Map<?, ?> answer = null;

		if (namespace != null) {
			answer = (Map)namespaceCache.get(
				new EqualityWeakReference<Namespace>(namespace));
		}

		if (answer == null) {
			answer = createMap();

			namespaceCache.put(
				new EqualityWeakReference<Namespace>(
					namespace, _namespaceCacheReferenceQueue),
				answer);
		}

		return answer;
	}

	private void _cleanReference(
		Map<Reference<?>, QName> map, ReferenceQueue<?> referenceQueue) {

		while (true) {
			Reference<?> reference = referenceQueue.poll();

			if (reference == null) {
				break;
			}

			map.remove(reference);
		}
	}

	private final DocumentFactory _documentFactory;
	private final ReferenceQueue<Namespace> _namespaceCacheReferenceQueue =
		new ReferenceQueue<Namespace>();
	private final ReferenceQueue<String> _noNamespaceCacheReferenceQueue =
		new ReferenceQueue<String>();

}