/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portlet.dynamicdatamapping.util.comparator;

import com.liferay.portal.kernel.util.CollatorUtil;
import com.liferay.portal.kernel.util.LocaleThreadLocal;
import com.liferay.portlet.dynamicdatamapping.model.DDMStructure;

import java.text.Collator;

import java.util.Comparator;
import java.util.Locale;

/**
 * @author Alberto Chaparro
 * @author Mariano Álvaro
 */
public class DDMStructureNameComparator implements Comparator<DDMStructure> {

	public DDMStructureNameComparator() {
		this(true, LocaleThreadLocal.getSiteDefaultLocale());
	}

	public DDMStructureNameComparator(Locale locale) {
		this(true, locale);
	}

	public DDMStructureNameComparator(boolean ascending, Locale locale) {
		_ascending = ascending;
		_locale = locale;

		_collator = CollatorUtil.getInstance(_locale);
	}

	@Override
	public int compare(DDMStructure DDMStructure1, DDMStructure DDMStructure2) {
		int value = _collator.compare(
			DDMStructure1.getName(_locale), DDMStructure2.getName(_locale));

		if (_ascending) {
			return value;
		}
		else {
			return - value;
		}
	}

	private final boolean _ascending;
	private final Locale _locale;
	private final Collator _collator;

}