/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portlet.nestedportlets.util;

import com.liferay.portal.kernel.servlet.JSPSupportServlet;
import com.liferay.portal.kernel.servlet.PersistentHttpServletRequestWrapper;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.model.LayoutSet;
import com.liferay.portal.util.WebKeys;

import javax.servlet.DispatcherType;
import javax.servlet.ServletContext;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletRequestWrapper;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.jsp.JspFactory;
import javax.servlet.jsp.PageContext;

/**
 * @author Eric Yan
 */
public class NestedPortletsUtil {

	/**
	 * @see com.liferay.portal.util.PortalImpl#getOriginalServletRequest
	 */
	public static PageContext getLastForwardRequest(PageContext pageContext) {
		HttpServletRequest currentRequest =
			(HttpServletRequest)pageContext.getRequest();
		HttpServletRequestWrapper currentRequestWrapper = null;
		HttpServletRequest originalRequest = null;
		HttpServletRequest nextRequest = null;
		HttpServletResponse response =
			(HttpServletResponse)pageContext.getResponse();

		while (currentRequest instanceof HttpServletRequestWrapper) {
			if (currentRequest instanceof
					PersistentHttpServletRequestWrapper) {

				PersistentHttpServletRequestWrapper
					persistentHttpServletRequestWrapper =
						(PersistentHttpServletRequestWrapper)currentRequest;

				persistentHttpServletRequestWrapper =
					persistentHttpServletRequestWrapper.clone();

				if (originalRequest == null) {
					originalRequest = persistentHttpServletRequestWrapper;
				}

				if (currentRequestWrapper != null) {
					currentRequestWrapper.setRequest(
						persistentHttpServletRequestWrapper);
				}

				currentRequestWrapper = persistentHttpServletRequestWrapper;
			}

			HttpServletRequestWrapper httpServletRequestWrapper =
				(HttpServletRequestWrapper)currentRequest;

			nextRequest =
				(HttpServletRequest)httpServletRequestWrapper.getRequest();

			if ((currentRequest.getDispatcherType() ==
					DispatcherType.FORWARD) &&
				(nextRequest.getDispatcherType() == DispatcherType.REQUEST)) {

				break;
			}

			currentRequest = nextRequest;
		}

		if ((currentRequestWrapper != null) &&
			!_isVirtualHostRequest(nextRequest)) {

			currentRequestWrapper.setRequest(currentRequest);
		}

		if (originalRequest != null) {
			return getPageContext(originalRequest, response);
		}

		return getPageContext(currentRequest, response);
	}

	public static PageContext getPageContext(
		HttpServletRequest request, HttpServletResponse response) {

		JspFactory jspFactory = JspFactory.getDefaultFactory();

		ServletContext servletContext = request.getServletContext();

		return jspFactory.getPageContext(
			new JSPSupportServlet(servletContext), request, response, null,
			false, 0, false);
	}

	private static boolean _isVirtualHostRequest(HttpServletRequest request) {
		LayoutSet layoutSet = (LayoutSet)request.getAttribute(
			WebKeys.VIRTUAL_HOST_LAYOUT_SET);

		if ((layoutSet != null) &&
			Validator.isNotNull(layoutSet.getVirtualHostname())) {

			return true;
		}

		return false;
	}

}