/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.kernel.cluster;

import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.security.pacl.permission.PortalRuntimePermission;

import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @author Tina Tian
 * @author Raymond Augé
 */
public class ClusterExecutorUtil {

	public static void addClusterEventListener(
		ClusterEventListener clusterEventListener) {

		ClusterExecutor clusterExecutor = getClusterExecutor();

		clusterExecutor.addClusterEventListener(clusterEventListener);
	}

	public static void destroy() {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		clusterExecutor.destroy();
	}

	public static FutureClusterResponses execute(ClusterRequest clusterRequest)
		throws SystemException {

		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.execute(clusterRequest);
	}

	public static void execute(
			ClusterRequest clusterRequest,
			ClusterResponseCallback clusterResponseCallback)
		throws SystemException {

		ClusterExecutor clusterExecutor = getClusterExecutor();

		clusterExecutor.execute(clusterRequest, clusterResponseCallback);
	}

	public static void execute(
			ClusterRequest clusterRequest,
			ClusterResponseCallback clusterResponseCallback, long timeout,
			TimeUnit timeUnit)
		throws SystemException {

		ClusterExecutor clusterExecutor = getClusterExecutor();

		clusterExecutor.execute(
			clusterRequest, clusterResponseCallback, timeout, timeUnit);
	}

	public static ClusterExecutor getClusterExecutor() {
		PortalRuntimePermission.checkGetBeanProperty(ClusterExecutorUtil.class);

		return _clusterExecutor;
	}

	public static List<Address> getClusterNodeAddresses() {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.getClusterNodeAddresses();
	}

	public static List<ClusterNode> getClusterNodes() {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.getClusterNodes();
	}

	public static ClusterNode getLocalClusterNode() throws SystemException {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.getLocalClusterNode();
	}

	public static Address getLocalClusterNodeAddress() {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.getLocalClusterNodeAddress();
	}

	public static void initialize() {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		clusterExecutor.initialize();
	}

	public static boolean isClusterNodeAlive(Address address) {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.isClusterNodeAlive(address);
	}

	public static boolean isClusterNodeAlive(String clusterNodeId) {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.isClusterNodeAlive(clusterNodeId);
	}

	public static boolean isEnabled() {
		ClusterExecutor clusterExecutor = getClusterExecutor();

		return clusterExecutor.isEnabled();
	}

	public static void removeClusterEventListener(
		ClusterEventListener clusterEventListener) {

		ClusterExecutor clusterExecutor = getClusterExecutor();

		clusterExecutor.removeClusterEventListener(clusterEventListener);
	}

	public void setClusterExecutor(ClusterExecutor clusterExecutor) {
		PortalRuntimePermission.checkSetBeanProperty(getClass());

		_clusterExecutor = clusterExecutor;
	}

	private static ClusterExecutor _clusterExecutor;

}