/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.kernel.increment;

/**
 * @author Shuyang Zhou
 */
public abstract class OverrideIncrement<T extends Comparable<T>>
	implements Increment<T> {

	public OverrideIncrement(T value) {
		this.value = value;
	}

	@Override
	public void decrease(T delta) {
		if (value.compareTo(delta) > 0) {
			value = delta;
		}
	}

	@Override
	public OverrideIncrement<T> decreaseForNew(T delta) {
		if (value.compareTo(delta) < 0) {
			delta = value;
		}

		return createOverrideIncrement(delta);
	}

	@Override
	public T getValue() {
		return value;
	}

	@Override
	public void increase(T delta) {
		if (value.compareTo(delta) < 0) {
			value = delta;
		}
	}

	@Override
	public OverrideIncrement<T> increaseForNew(T delta) {
		if (value.compareTo(delta) > 0) {
			delta = value;
		}

		return createOverrideIncrement(delta);
	}

	@Override
	public void setValue(T value) {
		this.value = value;
	}

	protected abstract OverrideIncrement<T> createOverrideIncrement(T value);

	protected T value;

}