/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.kernel.servlet.filters.compoundsessionid;

import com.liferay.portal.kernel.util.Props;
import com.liferay.portal.kernel.util.PropsKeys;
import com.liferay.portal.kernel.util.PropsUtil;
import com.liferay.portal.kernel.util.ServerDetector;
import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.kernel.util.Validator;

/**
 * <p>
 * See http://issues.liferay.com/browse/LPS-18587.
 * </p>
 *
 * @author Michael C. Han
 * @author Shuyang Zhou
 */
public class CompoundSessionIdSplitterUtil {

	public static String getSessionIdDelimiter() {
		return _sessionIdDelimiter;
	}

	public static boolean hasSessionDelimiter() {
		if (_sessionIdDelimiter == null) {
			Props props = PropsUtil.getProps();

			if (props == null) {
				return false;
			}

			String sessionIdDelimiter = props.get(
				PropsKeys.SESSION_ID_DELIMITER);

			if (Validator.isNull(sessionIdDelimiter)) {
				sessionIdDelimiter = props.get(
					"session.id." + ServerDetector.getServerId() +
						".delimiter");
			}

			if (Validator.isNotNull(sessionIdDelimiter)) {
				_sessionIdDelimiter = sessionIdDelimiter;

				return true;
			}
			else {
				_sessionIdDelimiter = StringPool.BLANK;

				return false;
			}
		}

		return !_sessionIdDelimiter.isEmpty();
	}

	public static String parseSessionId(String sessionId) {
		String sessionIdDelimiter = _sessionIdDelimiter;

		if (sessionIdDelimiter == null) {
			return sessionId;
		}

		int pos = sessionId.indexOf(sessionIdDelimiter);

		if (pos == -1) {
			return sessionId;
		}

		return sessionId.substring(0, pos);
	}

	private static volatile String _sessionIdDelimiter;

}