/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.kernel.util;

import java.io.Serializable;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

/**
 * @author Roberto Díaz
 */
public class EscapableLocalizableFunction implements Serializable {

	public EscapableLocalizableFunction(Function<Locale, String> function) {
		this(function, true);
	}

	public EscapableLocalizableFunction(
		Function<Locale, String> function, boolean escape) {

		_function = function;
		_escape = escape;
	}

	public String getEscapedValue(Locale locale) {
		if (_escapedValueMap.isEmpty() ||
			Validator.isNull(_escapedValueMap.get(locale))) {

			if (_escape) {
				_escapedValueMap.put(locale, escape(locale));
			}
			else {
				_escapedValueMap.put(locale, getOriginalValue(locale));
			}
		}

		return _escapedValueMap.get(locale);
	}

	public String getOriginalValue(Locale locale) {
		return _function.apply(locale);
	}

	protected String escape(Locale locale) {
		return HtmlUtil.escape(getOriginalValue(locale));
	}

	private final boolean _escape;
	private final Map<Locale, String> _escapedValueMap =
		new HashMap<Locale, String>();
	private final Function<Locale, String> _function;

}