/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * pSubscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.taglib.util;

import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.util.Portal;
import com.liferay.portal.util.PortalUtil;

import javax.servlet.ServletConfig;
import javax.servlet.http.HttpServletRequest;

/**
 * @author Preston Crary
 */
public class FriendlyURLUtil {

	public static String getFriendlyURL(
		HttpServletRequest request, ServletConfig servletConfig) {

		boolean privateParam = GetterUtil.getBoolean(
			servletConfig.getInitParameter("private"));

		String proxyPath = PortalUtil.getPathProxy();

		String friendlyURLPathPrefix = null;

		if (privateParam) {
			boolean userParam = GetterUtil.getBoolean(
				servletConfig.getInitParameter("user"));

			if (userParam) {
				friendlyURLPathPrefix =
					PortalUtil.getPathFriendlyURLPrivateUser();
			}
			else {
				friendlyURLPathPrefix =
					PortalUtil.getPathFriendlyURLPrivateGroup();
			}
		}
		else {
			friendlyURLPathPrefix = PortalUtil.getPathFriendlyURLPublic();
		}

		int pathInfoOffset =
			friendlyURLPathPrefix.length() - proxyPath.length();

		String pathInfo = null;

		String requestURI = request.getRequestURI();

		int pos = requestURI.indexOf(Portal.JSESSIONID);

		if (pos == -1) {
			pathInfo = requestURI.substring(pathInfoOffset);
		}
		else {
			pathInfo = requestURI.substring(pathInfoOffset, pos);
		}

		if (Validator.isNotNull(pathInfo)) {
			return friendlyURLPathPrefix.concat(pathInfo);
		}

		return friendlyURLPathPrefix;
	}

}